@@ -1,4 +1,6 @@
-from matplotlib.matlab import *
+#!/usr/bin/env python
+from pylab import *
+
 plot(arange(10))
 xlabel('this is a xlabel\n(with newlines!)')
 ylabel('this is vertical\ntest', multialignment='center')
