@@ -111,6 +111,20 @@ class Tick(Artist):
         self.label1On = label1On
         self.label2On = label2On
 
+    def get_children(self):
+        children = [self.tick1line, self.tick2line, self.gridline, self.label1, self.label2]
+        return children
+    
+    def pick(self, mouseevent):
+        """
+        pick(mouseevent)
+
+        each child artist will fire a pick event if mouseevent is over
+        the artist and the artist has picker set
+        """
+        for a in self.get_children():
+            a.pick(mouseevent)
+
     def set_pad(self, val):
         """
         Set the tick label pad in points
@@ -499,6 +513,22 @@ class Axis(Artist):
 
         self.cla()
 
+    def get_children(self):
+        children = [self.label]
+        children.extend(self.majorTicks)
+        children.extend(self.minorTicks)
+        return children
+    
+    def pick(self, mouseevent):
+        """
+        pick(mouseevent)
+
+        each child artist will fire a pick event if mouseevent is over
+        the artist and the artist has picker set
+        """
+        for a in self.get_children():
+            a.pick(mouseevent)
+
     def cla(self):
         'clear the current axis'
         self.set_major_locator(AutoLocator())
@@ -1099,14 +1129,14 @@ class YAxis(Axis):
         x,y = self.offsetText.get_position()
         top = self.axes.bbox.ymax()
         self.offsetText.set_position((x, top+self.OFFSETTEXTPAD*self.figure.dpi.get()/72.0))
-    
+
     def set_offset_position(self, position):
         assert position == 'left' or position == 'right'
-        
+
         x,y = self.offsetText.get_position()
         if position == 'left': x = 0
         else: x = 1
-        
+
         self.offsetText.set_ha(position)
         self.offsetText.set_position((x,y))
 
